diff src/share/vm/gc_implementation/g1/satbQueue.hpp @ 14909:4ca6dc0799b6

Backout jdk9 merge
author Gilles Duboscq <duboscq@ssw.jku.at>
date Tue, 01 Apr 2014 13:57:07 +0200
parents 89ac31a5a7a7
children 52b4284cb496
line wrap: on
line diff
--- a/src/share/vm/gc_implementation/g1/satbQueue.hpp	Tue Apr 01 14:09:03 2014 +0200
+++ b/src/share/vm/gc_implementation/g1/satbQueue.hpp	Tue Apr 01 13:57:07 2014 +0200
@@ -87,8 +87,7 @@
   bool apply_closure_to_completed_buffer_work(bool par, int worker);
 
 #ifdef ASSERT
-  void dump_active_states(bool expected_active);
-  void verify_active_states(bool expected_active);
+  void dump_active_values(JavaThread* first, bool expected_active);
 #endif // ASSERT
 
 public:
@@ -100,11 +99,11 @@
 
   static void handle_zero_index_for_thread(JavaThread* t);
 
   // Apply "set_active(active)" to all SATB queues in the set. It should be
   // called only with the world stopped. The method will assert that the
   // SATB queues of all threads it visits, as well as the SATB queue
   // set itself, has an active value same as expected_active.
-  void set_active_all_threads(bool active, bool expected_active);
+  void set_active_all_threads(bool b, bool expected_active);
 
   // Filter all the currently-active SATB buffers.
   void filter_thread_buffers();
@@ -100,11 +99,11 @@
   static void handle_zero_index_for_thread(JavaThread* t);
 
-  // Apply "set_active(active)" to all SATB queues in the set. It should be
+  // Apply "set_active(b)" to all Java threads' SATB queues. It should be
   // called only with the world stopped. The method will assert that the
   // SATB queues of all threads it visits, as well as the SATB queue